@@ -127,7 +127,10 @@ def get_database_config_file():
 
 def get_database_configuration():
     """Get database configuration as dictionary."""
-    with open(get_database_config_file(), 'r') as ymlfile:
+    db_config = get_database_config_file()
+    if db_config is None:
+        return None
+    with open(db_config, 'r') as ymlfile:
         cfg = yaml.load(ymlfile)
     return cfg
 
